Supreme Court Opinions | Tennessee Administrative Office of the Courts

# Tennessee Administrative Office of the Courts

### SEARCH TNCOURTS.GOV:

Search this site:
Administrative Office of the Courts
511 Union Street, Suite 600
Nashville, TN 37219
(615) 741-2687
(800) 448-7970

© 2013 Tennessee Courts System

## Supreme Court Opinions

Court
County
Authoring Judge
Originating Judge
Date Filter
Format: 08/30/2013
And:
Format: 08/30/2013
Case Number
Case Name
keyword search
Sort by:
Order:

William H. Mansell v. Bridgestone Firestone North American Tire, LLC et al. M2012-02394-WC-R3-WC Authoring Judge: Chief Justice Gary R. Wade Trial Court Judge: Judge John D. Wootten, Jr. After a benefit review conference in the Department of Labor and Workforce Development failed to produce a settlement, the employee filed suit for workers’ compensation benefits. Because the suit had already been filed, the trial court denied a request by the employer for an independent medical examination pursuant to the medical impairment rating (“MIR”) process in Tennessee Code Annotated section 50-6-204(d)(5) (2008 & Supp. 2012). After hearing all other proof relating to the claim, the trial court awarded compensation to the employee and questioned the constitutionality of the MIR process. The employer appealed; the Attorney General filed a brief as amicus curiae; and this Court vacated the judgment and remanded the cause for additional proceedings. On remand, the AttorneyGeneral was added as a defendant to address the constitutional issue. The trial court considered additional evidence, which included an MIR report by an independent medical examiner, and ruled that section 50-6-204(d)(5), which requires our courts to consider the opinion of an independent medical examiner appointed under that section as presumptively accurate, is an unconstitutional infringement upon the powers of the judiciary. In the alternative, the trial court held that the statutory presumption of the accuracy of the report, if compliant with constitutional principles, was overcome by the other medical evidence, and that the employee was entitled to a 10% permanent impairment rating rather than the 7% rating in the MIR report. In this appeal, the employer and the Attorney General argue that the statute meets constitutional standards. We hold that the MIR process does not violate constitutional principles, and we further find that the evidence did not clearly and convincingly rebut the statutory presumption. The judgment of the trial court is, therefore, reversed in part, and affirmed and modified in part. The cause is remanded for additional proceedings consistent with this opinion. | Smith County | Supreme Court | 08/20/13 |  |
Velda J. Shore v. Maple Lane Farms, LLC et al. E2011-00158-SC-R11-CV Authoring Judge: Justice William C. Koch, Jr. Trial Court Judge: Chancellor Telford E. Forgety, Jr. This appeal involves a dispute over the noise from amplified music concerts being conducted on farm land in rural Blount County. After the business owners who hosted the concerts defied the county zoning authority’s order limiting the concerts to one per year, a neighboring property owner filed suit in the Chancery Court for Blount County seeking to abate the concerts as a common-law nuisance and to enforce the decision of the county board of zoning appeals. The trial court granted the defendants’ motion for an involuntary dismissal at the close of the plaintiff’s proof, finding that the Tennessee Right to Farm Act, Tenn. Code Ann. §§ 43-26-101 to -104 (2007), precluded nuisance liability and that the concerts were exempted from the local land use regulations because they qualified as “agriculture.” The Court of Appeals affirmed. Shore v. Maple Lane Farms, LLC, No. E2011-00158-COA-R3-CV, 2012 WL 1245606 (Tenn. Ct. App. Apr. 11, 2012). We granted the plaintiff homeowner permission to appeal. We hold that the trial court erred by granting the motion to dismiss because the plaintiff homeowner presented a prima facie case of common-law nuisance and because the concerts are not “agriculture” for the purpose of the zoning laws. | Blount County | Supreme Court | 08/19/13 |  |
State of Tennessee v. Angela M. Merriman M2011-01682-SC-R11-CD Authoring Judge: Justice Janice M. Holder Trial Court Judge: Judge Larry B. Stanley, Jr. The defendant was arrested for driving under the influence, reckless endangerment with a motor vehicle, reckless driving, driving on a suspended license, and violation of the implied consent law. The arresting officer recorded his pursuit and stop of the defendant’s vehicle using video recording equipment installed in his patrol vehicle, but the video recording was subsequently lost. The defendant filed a motion to dismiss alleging that the State’s failure to preserve potentially exculpatory evidence would deprive her of a fair trial. Following a pre-trial evidentiary hearing, the trial court conducted an analysis under State v. Ferguson, 2 S.W.3d 912 (Tenn. 1999), and dismissed several of the charges. The Court of Criminal Appeals affirmed the trial court’s judgment, concluding that the trial court did not abuse its discretion in dismissing the charges. State v. Merriman, No. M2011-01682-CCA-R3-CD, 2012 WL 524474, at *3 (Tenn. Crim. App. Feb. 17, 2012). We granted the State permission to appeal. We apply a de novo standard of review and determine that, based on this record, the trial court did not err by finding that it would be fundamentally unfair to require the defendant to go to trial without the video recording. We also conclude that the trial court did not abuse its discretion in choosing dismissal as an appropriate remedy for the State’s loss of the video recording. | Warren County | Supreme Court | 08/16/13 |  |
Jim Hammond, Sheriff of Hamilton County et al. v. Chris Harvey et al. E2011-01700-SC-R11-CV Authoring Judge: Justice Sharon G. Lee Trial Court Judge: Chancellor W. Frank Brown, III The issue presented in this case is whether a county civil service board was authorized to order the county sheriff to equalize the pay of all sergeants employed within the sheriff’s office. A group of sergeants, who were paid varying amounts within an established pay range, filed a grievance regarding pay disparities among sergeants in the sheriff’s office. When the sheriff rejected the grievance, the sergeants filed a grievance with the sheriff’s department civil service board. The board upheld the grievance and ordered the sheriff to equalize the pay of all sergeants in the sheriff’s office. The sheriff and the county appealed to the Hamilton County Chancery Court, which held that the board did not have the authority to order pay equalization and declared the board’s ruling null and void. The Court of Appeals ruled that the board exceeded its statutory authority, but remanded the case to the board so it could direct the sheriff to take the necessary steps to eliminate the pay disparity. Pursuant to Tenn. Code Ann. § 8-8-409(3) (2011), we hold that the board had the authority to hear the grievance, but in the absence of proof that the sheriff violated state law or the sheriff’s department civil service manual, the board lacked the power to order the remedy of salary equalization. There was no proof that the sheriff violated state law, and the civil service manual specifically gave the sheriff the authority to make individual pay determinations. The judgment of the Court of Appeals is reversed, and the case is remanded to the Chancery Court for further proceedings as are necessary. | Hamilton County | Supreme Court | 08/13/13 |  |
State of Tennessee v. Dewayne Collier a/k/a Patrick Collier W2010-01606-SC-R11-CD Authoring Judge: Chief Justice Gary R. Wade Trial Court Judge: Judge John T. Fowlkes, Jr. A Shelby County jury convicted the defendant of aggravated statutory rape, and the trial court imposed a sentence of four years. On appeal, the defendant, who was forty-two years old at the time of the offense, argued that the evidence was insufficient to support his conviction because the testimony of the fourteen-year-old female victim, a consenting accomplice in the crime, was not adequately corroborated by other proof. The Court of Criminal Appeals found that the victim qualified as an accomplice to the crime but affirmed the conviction, holding that her testimony was sufficiently corroborated by the evidence in the record. This Court granted review to determine whether a victim of statutory rape qualifies as an accomplice such that his or her testimony must be corroborated in order to support a conviction. We hold that the testimony of a victim of statutory rape does not require corroboration. Because the evidence is sufficient to sustain the conviction, the judgment of the Court of Criminal Appeals is affirmed. | Shelby County | Supreme Court | 08/12/13 |  |
State of Tennessee v. Terrance Antonio Cecil M2011-01210-SC-R11-CD Authoring Judge: Chief Justice Gary R.Wade Trial Court Judge: Judge Robert L. Jones The defendant was convicted of false imprisonment and assault. The trial court imposed concurrent sentences of six months, with all but sixty days suspended to probation. More than one year after the trial but while the defendant’s case was pending in the Court of Criminal Appeals, this Court filed its opinion in State v. White, 362 S.W.3d 559 (Tenn. 2012), which requires, on grounds of due process, trial courts to provide a more specific instruction on kidnapping charges as to whether the removal or confinement of a victim is essentially incidental to any accompanying offense. The Court of Criminal Appeals held in this instance that, although the White instruction was not provided at trial, the jury was correctly instructed and the evidence was sufficient to support both convictions. We granted review to determine whether the absence of the White instruction warrants a new trial. Because the omission of the instruction required by White cannot be classified as harmless beyond a reasonable doubt, the conviction for false imprisonment is reversed and the cause remanded for a new trial. | Maury County | Supreme Court | 08/12/13 |  |
H. Owen Maddux v. Board of Professional Responsibility Of The Supreme Court Of Tennessee E2012-01809-SC-R3-BP Authoring Judge: Justice Cornelia A. Clark Trial Court Judge: Special Judge Donald P. Harris This direct appeal involves a disciplinary proceeding against a Chattanooga lawyer arising out of his representation of two clients. With one member dissenting, a hearing panel of the Board of Professional Responsibility determined that the lawyer should be suspended from the practice of law for nine months. The lawyer appealed to the Chancery Court for Hamilton County, and the trial court upheld the nine-month suspension, concluding that the evidence supported the finding of the hearing panel’s majority that the lawyer’s misconduct caused potential injury to one of his clients. In this appeal, the lawyer argues that (1) the hearing panel erred by refusing to set aside the default judgment entered against him based on his failure to respond to the petition for discipline; (2) the record contains no evidence of potential injury resulting from his misconduct; and (3) the hearing panel ascribed too much weight to his prior history of discipline when considering aggravating and mitigating circumstances. Based on our review of the record, we, like the trial court, affirm the hearing panel’s decision to suspend the lawyer’s license to practice law for nine months. | Hamilton County | Supreme Court | 08/09/13 |  |
Eddie C. Pratcher, Jr. v. Methodist Healthcare Memphis Hospitals et al. - DISSENT W2011-01576-SC-S09-CV Authoring Judge: Justice William C. Koch, Jr. Trial Court Judge: Judge Donna M. Fields This case has gone unresolved for far too long. It was finally tried more than six years after Ms. Pratcher’s death and after the filing of four amended complaints. After the jury returned a defendant’s verdict, the trial court granted a new trial because of a perceived shortcoming in the verdict form and because of its disagreementwith the jury’s verdict. With the second trial pending, one of the defendants sought to amend its answer to include a substantively meritorious defense based on the statute of repose in Tenn. Code Ann. § 29-26116(a)(3) (2012). With little explanation or analysis, the trial court denied the motion to amend on the ground of waiver. | Shelby County | Supreme Court | 06/28/13 |  |
Eddie C. Pratcher, Jr. v. Methodist Healthcare Memphis Hospitals et al. W2011-01576-SC-S09-CV Authoring Judge: Justice Sharon G. Lee Trial Court Judge: Judge Donna M. Fields The primary issue in this interlocutory appeal is whether the Tennessee health care liability statute of repose, Tenn. Code Ann. § 29-26-116(a)(3) (2012) (“the statute of repose”), is an affirmative defense under Tenn. R. Civ. P. 8.03, that is waived if not raised in a timely manner. Sandra Y. Jones Pratcher died following complications that arose on December 4, 1999, when she received anesthesia before undergoing a cesarean section. On December 1, 2000, her husband, Eddie C. Pratcher, Jr., (“Plaintiff”) filed suit against various health care providers, including Consultants in Anesthesia, Inc. (“Defendant”) and one of its nurse anesthetists. Plaintiff alleged that Defendant, which contracted with the hospital to provide anesthesia services to its obstetric patients, was vicariously liable for the negligent acts of its nurse anesthetist. Plaintiff amended his complaint on March 3, 2006, to assert that Defendant was also vicariously liable for the negligent actions of its corporate owner and president, Dr. Chauhan, who was on call on December 4, 1999, but failed to come to the hospital to administer anesthesia to Plaintiff’s wife. Plaintiff amended his complaint two more times and each time asserted that Defendant was vicariously liable for the negligent acts of Dr. Chauhan. Defendant did not raise the statute of repose as a defense to the vicarious liability claim based on Dr. Chauhan’s alleged negligence. After the jury returned a verdict for all defendants, the trial court set aside the verdict based on an error in the verdict form and its disapproval of the verdict as thirteenth juror. After the trial court granted a new trial as to all parties, Defendant moved to dismiss the case based on the statute of repose and to amend its answer to assert a statute of repose defense. The trial court ruled that Defendant had waived the statute of repose defense and denied the motions. We hold that (1) the running of the statute of repose does not deprive the trial court of subject matter jurisdiction; and (2) as Rule 8.03 explicitly states, the statute of repose is an affirmative defense. Defendant failed to timely raise the statute of repose as an affirmative defense. Therefore, the trial court did not abuse its discretion by denying Defendant’s posttrial motion to amend its answer to assert the statute of repose as a defense. The judgment of the trial court is affirmed. | Shelby County | Supreme Court | 06/28/13 |  |
State of Tennessee v. Michael Shane Springer W2010-02153-SC-R11-CD Authoring Judge: Justice Sharon G. Lee Trial Court Judge: Judge Clayburn Peeples In this appeal, we interpret the meaning of the phrase “term of imprisonment” in Articles III and IV of the Interstate Agreement on Detainers (“IAD”), Tenn. Code Ann. §§ 40-31-101 to -108 (2006), and determine whether the defendant is entitled to relief under the IAD. The IAD, a compact between state and federal jurisdictions, provides cooperative procedures for the exchange of prisoners between state and federal jurisdictions so that prisoners can be brought to trial on untried indictments or complaints. Under Article III of the IAD, a prisoner serving a term of imprisonment may request a trial within 180 days after being delivered to another state. Under Article IV of the IAD, an official of one jurisdiction may seek custody of a prisoner serving a term of imprisonment in another jurisdiction, but the prisoner must be tried within 120 days of arrival in that jurisdiction and cannot be “shuttled” back to the original place of imprisonment before the trial. The IAD mandates a dismissal of the indictment for a violation of either Article III or IV. The defendant in this case was arrested on related federal and state charges and taken into federal custody. After the defendant was tried and convicted in federal court, he was indicted by the grand jury in Gibson County on the related state charges. Before being sentenced in federal court, the defendant filed a demand for speedy disposition of the state charges under Article III of the IAD. While the defendant was confined at a federal temporary detention facility after his sentencing in federal court, the Gibson County Sheriff filed a detainer and transported the defendant to Gibson County for an arraignment. After counsel was appointed and the defendant was arraigned, he was transferred back into federal custody. The defendant filed a motion to dismiss the state indictment for violations of Articles III and IV of the IAD. The trial court denied the motion. The defendant entered a conditional guilty plea pursuant to Tenn. R. Crim. P. 11 and reserved a certified question of law seeking appellate review of the denial of the motion to dismiss because of the alleged violation of the IAD. The Court of Criminal Appeals, in a divided opinion, affirmed the trial court’s denial of the defendant’s motion to dismiss. See State v. Springer, No. W2010-02153-CCA-R3-CD, 2012 WL 603820, at *1 (Tenn. Crim. App. Feb. 16, 2012). We hold that for purposes of the IAD, a prisoner who is incarcerated after sentencing is serving a “term of imprisonment.” We further hold that the defendant properly reserved his issues for appeal in the certified question; that the defendant was a federal pretrial detainee at the time he filed a procedurally deficient demand for speedy disposition and is not entitled to relief under Article III; and that the defendant was serving a term of imprisonment when he was transferred, pursuant to a detainer, from the federal temporary detention facility to Gibson County for his arraignment and back to federal custody on the same day. Article IV of the IAD was violated when the defendant was transferred back to the federal detention center before being tried for the state charges. The judgment of the Court of Criminal Appeals is reversed, the conviction is vacated, and the indictment against the defendant is dismissed with prejudice. | Gibson County | Supreme Court | 06/24/13 |  |
Walter Ray Culp, III v. Board of Professional Responsibility for the Supreme Court of Tennessee M2012-01816-SC-R3-BP Authoring Judge: Justice Sharon G. Lee Trial Court Judge: Judge Walter C. Kurtz In this appeal, we review the denial of an attorney’s petition for reinstatement of his law license. The attorney was suspended from the practice of law for five years after he pleaded guilty to attempted extortion in federal court. The extortion arose out of the attorney’s attempt to broker the testimony of a witness in a civil trial for a substantial fee. After serving a nineteen-month prison sentence and a five-year suspension from the practice of law, the attorney petitioned for reinstatement. A hearing panel of the Board of Professional Responsibility denied the attorney’s request, finding that the attorney failed to carry his burden of proof by clear and convincing evidence that he had the moral qualifications, competency and learning in law, and that reinstatement would not be detrimental to the integrity and standing of the bar, the administration of justice and subversive to the public interest. The panel considered, among other things, the nature of the crime, that the extortion involved several million dollars, the attorney’s unwillingness to take responsibility for his actions, and his lack of credibility. The attorney appealed to the Chancery Court for Williamson County. The trial court affirmed the hearing panel’s decision. We affirm the decision of the trial court. | Williamson County | Supreme Court | 06/24/13 |  |
State of Tennessee v. Ledarren S. Hawkins W2010-01687-SC-R11-CD Authoring Judge: Justice William C. Koch, Jr. Trial Court Judge: Judge Roy B. Morgan, Jr. The defendant was convicted in the Circuit Court for Madison County of first degree murder and tampering with physical evidence. On this appeal, the defendant seeks reversal of his first degree murder conviction on the ground that the trial court declined his request for a jury instruction on defense of a third person. He also seeks reversal of his evidence-tampering conviction on the ground that his abandonment of the murder weapon did not amount to tampering with physical evidence. The Court of Criminal Appeals upheld his convictions and sentences. State v. Hawkins, No.W2010-01687-CCA-R3-CD, 2012 WL 543048 (Tenn. Crim. App. Feb. 16, 2012). Based on this record, we have determined that the trial court properly denied the defendant’s request for an instruction on defense of a third person. However, we have also determined that the defendant did not tamper with physical evidence in violation of Tenn.Code Ann.§ 39-16-503(a)(1)(2010) by tossing the murder weapon over a short fence where it could be easily observed and recovered. Accordingly, we affirm the defendant’s conviction and sentence for first degree murder and reverse his conviction and sentence for tampering with physical evidence. | Madison County | Supreme Court | 06/20/13 |  |
Herbert S. Moncier v. Board of Professional Responsibility E2012-00340-SC-R3-BP Authoring Judge: Justice Cornelia A. Clark Trial Court Judge: An attorney suspended from the practice of law for eleven months and twenty-nine days,with all but forty-five days of the suspension probated, was assessed costs associated with the proceedings that resulted in his suspension pursuant to Tennessee Supreme Court Rule 9, section 24.3. The attorney timely filed a petition seeking relief from costs, and a panel of the Board of Professional Responsibility convened and conducted a hearing on the petition. The panel denied the petition, and the attorney has appealed to this Court, as permitted by Rule 9, section 24.3. Having carefully and thoroughly considered the record and each of the nine issues raised, we affirm the panel’s decision denying the petition for relief from costs. |  | Supreme Court | 05/24/13 |  |

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »